@@ -23,8 +23,8 @@
 #include "fileaccess.h"
 #include "optiondialog.h"
 
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include <tqfileinfo.h>
 #include <tqdir.h>
 #include <tqtextcodec.h>
