@@ -34,8 +34,8 @@
 #include <math.h>
 #include <cstdlib>
 #include <tqdragobject.h>
-#include <klocale.h>
-#include <kfiledialog.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
 
 class DiffTextWindowData
 {
