@@ -34,8 +34,8 @@
 #include <tqtextcodec.h>
 #include <tqdragobject.h>
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <iostream>
 
 int g_bAutoSolve = true;
